<?php

/*
 * This file is part of the FOSUserBundle package.
 *
 * (c) FriendsOfSymfony <http://friendsofsymfony.github.com/>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace UBV\AutenticacionBundle\Form\Type;

use FOS\UserBundle\Util\LegacyFormHelper;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\FormBuilderInterface;
use UBV\SurUbvBundle\Form\AspiranteCandidatoType;
use UBV\SurUbvBundle\Entity\Aspirante;
use UBV\SurUbvBundle\Form\PersonaNacionalidadType;
use UBV\SurUbvBundle\Entity\PersonaNacionalidad;

use UBV\SurUbvBundle\Form\PersonaTelefonoType;
use UBV\SurUbvBundle\Entity\PersonaTelefono;

use UBV\SurUbvBundle\Form\PersonaCorreoType;
use UBV\SurUbvBundle\Entity\PersonaCorreo;

use UBV\SurUbvBundle\Form\EstudianteDocumentoType;
use UBV\SurUbvBundle\Entity\EstudianteDocumento;

use Symfony\Component\OptionsResolver\OptionsResolver;
use Symfony\Component\Form\Extension\Core\Type\CollectionType;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;
use  Symfony\Component\Validator\Constraints\NotBlank;
use Symfony\Component\Validator\Constraints\Length;

class RegistrationAspirantePreGradoType extends AbstractType
{
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        // add your custom field
      
        $builder                    
              ->add('email', LegacyFormHelper::getType('Symfony\Component\Form\Extension\Core\Type\EmailType'), array(
                'disabled'=>true,
                'attr'       => array('class' => 'form-control'),
                'label_attr' => array('class' => 'control-label'),
                'label' => 'Correo Académico',
                'translation_domain' => 'FOSUserBundle'
              
              ))
                
              ->add('username', null, array(
                'disabled'=>true,
                'label'=>'Nombre de Usuario',
                'attr'       => array('class' => 'form-control','placeholder'=>''),
                'label_attr' => array('class' => 'control-label'),
            ))
                
              ->add('plainPassword', LegacyFormHelper::getType('Symfony\Component\Form\Extension\Core\Type\RepeatedType'), array(
                'type' => LegacyFormHelper::getType('Symfony\Component\Form\Extension\Core\Type\PasswordType'),
                'options' => array('translation_domain' => 'FOSUserBundle'),
                'first_options' => array(
                    'label' => 'form.password',
                    'attr'       => array('class' => 'form-control','placeholder'=>''),
                    'label_attr' => array('class' => 'control-label'),
                  ),
                'second_options' => array(
                    'label' => 'form.password_confirmation',
                    'attr'       => array('class' => 'form-control','placeholder'=>''),
                    'label_attr' => array('class' => 'control-label'),
                  ),
                'invalid_message' => 'fos_user.password.mismatch',
            ))
            
              ->add('primerNombre', null, array(
                'disabled'=>true,
                'constraints' => new NotBlank(array('groups' => array('Default'))),
                'attr'       => array('class' => 'form-control'),
                'label_attr' => array('class' => 'control-label'),
            ))
                 
              ->add('genero', EntityType::class, array(
                'disabled'=>true,
                'class' => 'UBVSurUbvBundle:Genero',
                'label'      =>"Genero",
                'empty_data' => "0",
                'placeholder'=>"Seleccione...",
                'attr'       => array('class' => 'form-control form-control-choice','placeholder'=>''),
                'label_attr' => array('class' => 'control-label'),
            ))
        
              ->add('segundoNombre', null, array(
                'disabled'=>true,
                'label'=>'Segundo Nombre',
                'attr'       => array('class' => 'form-control','placeholder'=>''),
                'label_attr' => array('class' => 'control-label'),
            ))
        
              ->add('primerApellido', null, array(
                'disabled'=>true,
                'constraints' => new NotBlank(array('groups' => array('Default'))),
                'label'=>'Primer Apellido',
                'attr'       => array('class' => 'form-control','placeholder'=>''),
                'label_attr' => array('class' => 'control-label'),
            ))
        
              ->add('segundoApellido', null, array(
                'disabled'=>true,
                'label'=>'Segundo Apellido',
                'attr'       => array('class' => 'form-control','placeholder'=>''),
                'label_attr' => array('class' => 'control-label'),
            ))
        
              ->add('fechaNacimiento', "Symfony\Component\Form\Extension\Core\Type\DateType", array(
              'disabled'=>true,
              'constraints' => new NotBlank(array('groups' => array('Default'))),
              'widget' => 'single_text',
              'format' => 'dd-MM-yyyy',
              'label'=> 'Fecha de Nacimiento',
              'attr' => array('class' => 'datepicker-default form-control','data-date-format'=>"dd/mm/yyyy" ),
              'label_attr' => array('class' => 'control-label')
            ))
                      
              ->add('estadoCivil', EntityType::class, array(
                'disabled'=>true,
                'class' => 'UBVSurUbvBundle:EstadoCivil',
                'label'      =>"Estado Civil",
                'empty_data' => "0",
                'placeholder'=>"Seleccione...",
                'attr'       => array('class' => 'form-control form-control-choice','placeholder'=>''),
                'label_attr' => array('class' => 'control-label'),
            ))
              
              ->add('pais', EntityType::class, array(
                'class' => 'UBVSurUbvBundle:Pais',
                'label'      =>"País de Nacimiento",
                'empty_data' => "0",
                'placeholder'=>"Seleccione...",
                'attr'       => array('class' => 'form-control form-control-choice','placeholder'=>''),
                'label_attr' => array('class' => 'control-label'),
            ))
              
              ->add('aspirantes', CollectionType::class, array(
                'constraints'=> new NotBlank(array('groups' => array('Default'))),
                'entry_type'     => AspiranteCandidatoType::class,
                'label'          => 'Aspirante',
                'by_reference'   => true,
                'prototype_data' => new Aspirante(),
                'allow_delete'   => true,
                'allow_add'      => true,
                'attr'           => array('class' => 'row aspirante')
            ))
              ->add('personaNacionalidads', CollectionType::class, array(
                
                'constraints'=> new NotBlank(array('groups' => array('Default'))),
                'entry_type'     => PersonaNacionalidadType::class,
                'label'          => 'Nacionalidad',
                'by_reference'   => true,
                'prototype_data' => new PersonaNacionalidad(),
                'allow_delete'   => true,
                'allow_add'      => true,
                'attr'           => array('class' => 'row nacionalidad')
            ))
                
            ->add('personaCorreos', CollectionType::class, array(
                'disabled'=>true,
                'constraints'=> new NotBlank(array('groups' => array('Default'))),
                'entry_type'     => PersonaCorreoType::class,
                'label'          => 'Correo',
                'by_reference'   => true,
                'prototype_data' => new PersonaCorreo(),
                'allow_delete'   => true,
                'allow_add'      => true,
                'attr'           => array('class' => 'row correo')
            ))
            
            ->add('personaTelefonos', CollectionType::class, array(
                'constraints'=> new NotBlank(array('groups' => array('Default'))),
                'entry_type'     => PersonaTelefonoType::class,
                'label'          => 'Telefono',
                'by_reference'   => true,
                'prototype_data' => new PersonaTelefono(),
                'allow_delete'   => true,
                'allow_add'      => true,
                'attr'           => array('class' => 'row correo')
            ))
                
            /*->add('groups', EntityType::class, array(
                //'disabled'=>true,
                'multiple' => false,
                'expanded' => false,
                'class' => 'UBVSurUbvBundle:Grupo',
                'label'      =>"Grupo Asignado",
                'empty_data' => "0",
                'placeholder'=>"Seleccione...",
                'attr'       => array('class' => 'form-control form-control-choice','placeholder'=>''),
                'label_attr' => array('class' => 'control-label'),
            ))*/;
    }
				
    public function configureOptions(OptionsResolver $resolver)
    {
        $resolver->setDefaults(array(
            'data_class' => 'UBV\SurUbvBundle\Entity\Persona',
            'constrints' => true,
            'validation_groups' => true,
        ));
    }

    public function getBlockPrefix()
    {
        return 'app_user_registration_pregrado';
    }
    
    public function getName()
    {
        return $this->getBlockPrefix();
    }
}