<?php

/*
 * This file is part of the FOSUserBundle package.
 *
 * (c) FriendsOfSymfony <http://friendsofsymfony.github.com/>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace UBV\AutenticacionBundle\Form\Type;
use FOS\UserBundle\Util\LegacyFormHelper;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\FormBuilderInterface;
use UBV\SurUbvBundle\Form\AspiranteType;
use UBV\SurUbvBundle\Entity\Aspirante;
use UBV\SurUbvBundle\Form\PersonaNacionalidadType;
use UBV\SurUbvBundle\Entity\PersonaNacionalidad;

use UBV\SurUbvBundle\Form\EventListener\AddPaisFieldSubscriber;
use UBV\SurUbvBundle\Form\EventListener\AddEstadoFieldSubscriber;
use UBV\SurUbvBundle\Form\EventListener\AddMunicipioFieldSubscriber;
use UBV\SurUbvBundle\Form\EventListener\AddParroquiaFieldSubscriber;

use UBV\SurUbvBundle\Form\EventListener\AddEjeMunicipalFieldSubscriber;
use UBV\SurUbvBundle\Form\EventListener\AddEjeRegionalFieldSubscriber;

use UBV\SurUbvBundle\Form\EstudianteDocumentoType;
use UBV\SurUbvBundle\Entity\EstudianteDocumento;

use Symfony\Component\OptionsResolver\OptionsResolver;
use Symfony\Component\Form\Extension\Core\Type\CollectionType;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;
use  Symfony\Component\Validator\Constraints\NotBlank;
use Symfony\Component\Validator\Constraints\Length;

class RegistrationAspiranteType extends AbstractType
{
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        // add your custom field
      
        $propertyPathToEstado = 'estado';
            $propertyPathToMunicipio = 'municipios';
            $propertyPathToEjeMunicipal = 'ejemunicipal';
            $propertyPathToParroquia = 'parroquia';
            $propertyPathToAmbiente = 'ambiente';
            $builder
            ->addEventSubscriber(new AddPaisFieldSubscriber($propertyPathToAmbiente))
            ->addEventSubscriber(new AddEstadoFieldSubscriber($propertyPathToAmbiente))
            ->addEventSubscriber(new AddMunicipioFieldSubscriber($propertyPathToAmbiente))
            ->addEventSubscriber(new AddParroquiaFieldSubscriber($propertyPathToAmbiente))
            ->addEventSubscriber(new AddAmbienteFieldSubscriber($propertyPathToAmbiente))
            ->addEventSubscriber(new AddEjeRegionalFieldSubscriber($propertyPathToAmbiente))
            ->addEventSubscriber(new AddEjeMunicipalFieldSubscriber($propertyPathToAmbiente))
              ->add('email', LegacyFormHelper::getType('Symfony\Component\Form\Extension\Core\Type\EmailType'), array(
                'attr'       => array('class' => 'form-control'),
                'label_attr' => array('class' => 'control-label'),
                'label' => 'form.email',
                'translation_domain' => 'FOSUserBundle'
              
              ))
                
              ->add('username', null, array(
                'label'=>'Nombre de Usuario',
                'attr'       => array('class' => 'form-control','placeholder'=>''),
                'label_attr' => array('class' => 'control-label'),
            ))
                
              ->add('plainPassword', LegacyFormHelper::getType('Symfony\Component\Form\Extension\Core\Type\RepeatedType'), array(
                'type' => LegacyFormHelper::getType('Symfony\Component\Form\Extension\Core\Type\PasswordType'),
                'options' => array('translation_domain' => 'FOSUserBundle'),
                'first_options' => array(
                    'label' => 'form.password',
                    'attr'       => array('class' => 'form-control','placeholder'=>''),
                    'label_attr' => array('class' => 'control-label'),
                  ),
                'second_options' => array(
                    'label' => 'form.password_confirmation',
                    'attr'       => array('class' => 'form-control','placeholder'=>''),
                    'label_attr' => array('class' => 'control-label'),
                  ),
                'invalid_message' => 'fos_user.password.mismatch',
            ))
            
              ->add('primerNombre', null, array(
                'constraints' => new NotBlank(array('groups' => array('Default'))),
                'attr'       => array('class' => 'form-control'),
                'label_attr' => array('class' => 'control-label'),
            ))
                 
              ->add('genero', EntityType::class, array(
                'class' => 'UBVSurUbvBundle:Genero',
                'label'      =>"Genero",
                'empty_data' => "0",
                'placeholder'=>"Seleccione...",
                'attr'       => array('class' => 'form-control form-control-choice','placeholder'=>''),
                'label_attr' => array('class' => 'control-label'),
            ))
        
              ->add('segundoNombre', null, array(

                'label'=>'Segundo Nombre',
                'attr'       => array('class' => 'form-control','placeholder'=>''),
                'label_attr' => array('class' => 'control-label'),
            ))
        
              ->add('primerApellido', null, array(
                'constraints' => new NotBlank(array('groups' => array('Default'))),
                'label'=>'Primer Apellido',
                'attr'       => array('class' => 'form-control','placeholder'=>''),
                'label_attr' => array('class' => 'control-label'),
            ))
        
              ->add('segundoApellido', null, array(
                'label'=>'Segundo Apellido',
                'attr'       => array('class' => 'form-control','placeholder'=>''),
                'label_attr' => array('class' => 'control-label'),
            ))
        
              ->add('fechaNacimiento', "Symfony\Component\Form\Extension\Core\Type\DateType", array(
              'constraints' => new NotBlank(array('groups' => array('Default'))),
              'widget' => 'single_text',
              'format' => 'dd-MM-yyyy',
              'label'=> 'Fecha de Nacimiento',
              'attr' => array('class' => 'datepicker-default form-control','data-date-format'=>"dd/mm/yyyy" ),
              'label_attr' => array('class' => 'control-label')
            ))
                      
              ->add('estadoCivil', EntityType::class, array(
                'class' => 'UBVSurUbvBundle:EstadoCivil',
                'label'      =>"Estado Civil",
                'empty_data' => "0",
                'placeholder'=>"Seleccione...",
                'attr'       => array('class' => 'form-control form-control-choice','placeholder'=>''),
                'label_attr' => array('class' => 'control-label'),
            ))
              
              ->add('pais', EntityType::class, array(
                'class' => 'UBVSurUbvBundle:Pais',
                'label'      =>"País de Nacimiento",
                'empty_data' => "0",
                'placeholder'=>"Seleccione...",
                'attr'       => array('class' => 'form-control form-control-choice','placeholder'=>''),
                'label_attr' => array('class' => 'control-label'),
            ))
              
              ->add('aspirantes', CollectionType::class, array(
                'cascade_validation'=>true,  
                'entry_type'     => AspiranteType::class,
                'label'          => 'Aspirante',
                'by_reference'   => true,
                'prototype_data' => new Aspirante(),
                'allow_delete'   => true,
                'allow_add'      => true,
                'attr'           => array('class' => 'row aspirante')
            ))
              ->add('personaNacionalidads', CollectionType::class, array(
                'entry_type'     => PersonaNacionalidadType::class,
                'label'          => 'Nacionalidad',
                'by_reference'   => true,
                'prototype_data' => new PersonaNacionalidad(),
                'allow_delete'   => true,
                'allow_add'      => true,
                'attr'           => array('class' => 'row nacionalidad')
            ))
                
            ->add('estudianteDocumentos', CollectionType::class, array(
                'entry_type'     => EstudianteDocumentoType::class,
                'allow_add'    => true,
                'label'          => 'Documento',
                'by_reference'   => true,
                'prototype_data' => new EstudianteDocumento(),
                'allow_delete'   => true,
                'allow_add'      => true,
                'attr'           => array('class' => 'row documento')
            ))    
                
          ;
    }
				
    public function configureOptions(OptionsResolver $resolver)
    {
        $resolver->setDefaults(array(
            'data_class' => 'UBV\SurUbvBundle\Entity\Persona',
            'constrints' => true,
            'validation_groups' => true,
        ));
    }

    

    public function getBlockPrefix()
    {
        return 'app_user_registration_aspirante';
    }
    
    public function getName()
    {
        return $this->getBlockPrefix();
    }
}