<?php

/*
 * This file is part of the FOSUserBundle package.
 *
 * (c) FriendsOfSymfony <http://friendsofsymfony.github.com/>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace UBV\AutenticacionBundle\Form\Type;
use FOS\UserBundle\Util\LegacyFormHelper;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\FormBuilderInterface;
use UBV\SurUbvBundle\Form\AspiranteType;
use UBV\SurUbvBundle\Entity\Aspirante;
use UBV\SurUbvBundle\Form\PersonaNacionalidadRegisterType;
use UBV\SurUbvBundle\Entity\PersonaNacionalidad;

use UBV\SurUbvBundle\Form\EventListener\AddPaisFieldSubscriber;
use UBV\SurUbvBundle\Form\EventListener\AddEstadoFieldSubscriber;
use UBV\SurUbvBundle\Form\EventListener\AddMunicipioFieldSubscriber;
use UBV\SurUbvBundle\Form\EventListener\AddParroquiaFieldSubscriber;

use UBV\SurUbvBundle\Form\EventListener\AddEjeMunicipalFieldSubscriber;
use UBV\SurUbvBundle\Form\EventListener\AddEjeRegionalFieldSubscriber;

use UBV\SurUbvBundle\Form\PersonaTelefonoType;
use UBV\SurUbvBundle\Entity\PersonaTelefono;

use UBV\SurUbvBundle\Form\PersonaCorreoRegisterType;
use UBV\SurUbvBundle\Entity\PersonaCorreo;

use UBV\SurUbvBundle\Form\EstudianteDocumentoType;
use UBV\SurUbvBundle\Entity\EstudianteDocumento;

use UBV\SurUbvBundle\Form\PersonalAdministrativoType;
use UBV\SurUbvBundle\Entity\PersonalAdministrativo;

use Symfony\Component\OptionsResolver\OptionsResolver;
use Symfony\Component\Form\Extension\Core\Type\CollectionType;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;
use Symfony\Component\Validator\Constraints\NotBlank;
use Symfony\Component\Validator\Constraints\Length;

class RegistrationPersonaType extends AbstractType
{
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        // add your custom field
      
            $builder                                    
              ->add('plainPassword', LegacyFormHelper::getType('Symfony\Component\Form\Extension\Core\Type\RepeatedType'), array(
                'type' => LegacyFormHelper::getType('Symfony\Component\Form\Extension\Core\Type\PasswordType'),
                'options' => array('translation_domain' => 'FOSUserBundle'),
                'first_options' => array(
                    'label' => 'form.password',
                    'attr'       => array('class' => 'form-control','placeholder'=>''),
                    'label_attr' => array('class' => 'control-label'),
                  ),
                'second_options' => array(
                    'label' => 'form.password_confirmation',
                    'attr'       => array('class' => 'form-control','placeholder'=>''),
                    'label_attr' => array('class' => 'control-label'),
                  ),
                'invalid_message' => 'fos_user.password.mismatch',
            ))
                    
              ->add('groups', EntityType::class, array(
                'multiple' => true,   // Multiple selection allowed
                'expanded' => true,   // Render as checkboxes
                'choice_label' => 'name', // Assuming that the entity has a "name" property
                'class'    => 'UBVSurUbvBundle:Grupo',
                'label_attr' => array('class' => 'control-label'),
            ))
            
              ->add('primerNombre', null, array(
                'constraints' => new NotBlank(array('groups' => array('Default'))),
                'attr'       => array('class' => 'form-control'),
                'label_attr' => array('class' => 'control-label'),
            ))
                 
              ->add('genero', EntityType::class, array(
                'class' => 'UBVSurUbvBundle:Genero',
                'label'      =>"Genero",
                'empty_data' => "0",
                'placeholder'=>"Seleccione...",
                'attr'       => array('class' => 'form-control form-control-choice','placeholder'=>''),
                'label_attr' => array('class' => 'control-label'),
            ))
        
              ->add('segundoNombre', null, array(
                'label'=>'Segundo Nombre',
                'attr'       => array('class' => 'form-control','placeholder'=>''),
                'label_attr' => array('class' => 'control-label'),
            ))
        
              ->add('primerApellido', null, array(
                'constraints' => new NotBlank(array('groups' => array('Default'))),
                'label'=>'Primer Apellido',
                'attr'       => array('class' => 'form-control','placeholder'=>''),
                'label_attr' => array('class' => 'control-label'),
            ))
        
              ->add('segundoApellido', null, array(
                'label'=>'Segundo Apellido',
                'attr'       => array('class' => 'form-control','placeholder'=>''),
                'label_attr' => array('class' => 'control-label'),
            ))
        
              ->add('fechaNacimiento', "Symfony\Component\Form\Extension\Core\Type\DateType", array(
              'constraints' => new NotBlank(array('groups' => array('Default'))),
              'widget' => 'single_text',
              'format' => 'dd-MM-yyyy',
              'label'=> 'Fecha de Nacimiento',
              'attr' => array('class' => 'datepicker-default form-control','data-date-format'=>"dd/mm/yyyy" ),
              'label_attr' => array('class' => 'control-label')
            ))
                      
              ->add('estadoCivil', EntityType::class, array(
                'class' => 'UBVSurUbvBundle:EstadoCivil',
                'label'      =>"Estado Civil",
                'empty_data' => "0",
                'placeholder'=>"Seleccione...",
                'attr'       => array('class' => 'form-control form-control-choice','placeholder'=>''),
                'label_attr' => array('class' => 'control-label'),
            ))
              
              ->add('pais', EntityType::class, array(
                'class' => 'UBVSurUbvBundle:Pais',
                'label'      =>"País de Nacimiento",
                'empty_data' => "0",
                'placeholder'=>"Seleccione...",
                'attr'       => array('class' => 'form-control form-control-choice','placeholder'=>''),
                'label_attr' => array('class' => 'control-label'),
            ))
              
              ->add('personaNacionalidads', CollectionType::class, array(
                //'constraints'=> new NotBlank(array('groups' => array('Default'))),
                'entry_type'     => PersonaNacionalidadRegisterType::class,
                'label'          => 'Nacionalidad',
                'by_reference'   => true,
                'prototype_data' => new PersonaNacionalidad(),
                'allow_delete'   => true,
                'allow_add'      => true,
                'attr'           => array('class' => 'nacionalidad')
            ))
                
            ->add('personaCorreos', CollectionType::class, array(
                //'constraints'=> new NotBlank(array('groups' => array('Default'))),
                'entry_type'     => PersonaCorreoRegisterType::class,
                'label'          => 'Correo',
                'by_reference'   => true,
                'prototype_data' => new PersonaCorreo(),
                'allow_delete'   => true,
                'allow_add'      => true,
                'attr'           => array('class' => 'row correo')
            ))
            
            ->add('personalAdministrativos', CollectionType::class, array(
                'constraints'=> new NotBlank(array('groups' => array('Default'))),
                'entry_type'     => PersonalAdministrativoType::class,
                'label'          => 'Unidad Administrativa',
                'by_reference'   => true,
                'prototype_data' => new PersonalAdministrativo(),
                'allow_delete'   => true,
                'allow_add'      => true,
                'attr'           => array('class' => 'row personalAdministrativo')
            ))
            
            ->add('personaTelefonos', CollectionType::class, array(
                //'constraints'=> new NotBlank(array('groups' => array('Default'))),
                'entry_type'     => PersonaTelefonoType::class,
                'label'          => 'Telefono',
                'by_reference'   => true,
                'prototype_data' => new PersonaTelefono(),
                'allow_delete'   => true,
                'allow_add'      => true,
                'attr'           => array('class' => 'row correo')
            ));
    }
				
    public function configureOptions(OptionsResolver $resolver)
    {
        $resolver->setDefaults(array(
            'data_class' => 'UBV\SurUbvBundle\Entity\Persona',
            'constrints' => true,
            'validation_groups' => array("Registration","Default"),
        ));
    }

    public function getBlockPrefix()
    {
        return 'app_user_persona_registration';
    }
    
    public function getName()
    {
        return $this->getBlockPrefix();
    }
}