<?php

namespace UBV\SurUbvBundle\Controller;

use Symfony\Component\HttpFoundation\Request;
use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Method;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use UBV\SurUbvBundle\Entity\Ambiente;
use UBV\SurUbvBundle\Form\AmbienteType;
use Symfony\Component\HttpFoundation\JsonResponse;

/**
 * Ambiente controller.
 *
 * @Route("/ambiente")
 */
class AmbienteController extends Controller
{
    /**
     * Lists all Ambiente entities.
     *
     * @Route("/", name="ambiente_index")
     * @Method("GET")
     */
    public function indexAction()
    {
        $em = $this->getDoctrine()->getManager();

        $ambientes = $em->getRepository('UBVSurUbvBundle:Ambiente')->findAll();

        return $this->render('ambiente/index.html.twig', array(
            'ambientes' => $ambientes,
        ));
    }

    /**
     * 
     * @Route("/ambientes", name="select_ambientes")
     * @Method("POST")
     */
    public function ambientesAction(Request $request) {
      $parroquia_id = $request->request->get('parroquia_id');
      $em = $this->getDoctrine()->getManager();
      $ambiente = $em->getRepository('UBVSurUbvBundle:Ambiente')->findEstadosByPaisId($parroquia_id);

      return new JsonResponse($ambiente);
    }
    
    /**
     * Creates a new Ambiente entity.
     *
     * @Route("/new", name="ambiente_new")
     * @Method({"GET", "POST"})
     */
    public function newAction(Request $request)
    {
        $ambiente = new Ambiente();
        $form = $this->createForm('UBV\SurUbvBundle\Form\AmbienteType', $ambiente);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $em = $this->getDoctrine()->getManager();
            $em->persist($ambiente);
            $em->flush();

            return $this->redirectToRoute('ambiente_show', array('id' => $ambiente->getId()));
        }

        return $this->render('ambiente/new.html.twig', array(
            'ambiente' => $ambiente,
            'form' => $form->createView(),
        ));
    }

    /**
     * Finds and displays a Ambiente entity.
     *
     * @Route("/{id}", name="ambiente_show")
     * @Method("GET")
     */
    public function showAction(Ambiente $ambiente)
    {
        $deleteForm = $this->createDeleteForm($ambiente);

        return $this->render('ambiente/show.html.twig', array(
            'ambiente' => $ambiente,
            'delete_form' => $deleteForm->createView(),
        ));
    }

    /**
     * Displays a form to edit an existing Ambiente entity.
     *
     * @Route("/{id}/edit", name="ambiente_edit")
     * @Method({"GET", "POST"})
     */
    public function editAction(Request $request, Ambiente $ambiente)
    {
        $deleteForm = $this->createDeleteForm($ambiente);
        $editForm = $this->createForm('UBV\SurUbvBundle\Form\AmbienteType', $ambiente);
        $editForm->handleRequest($request);

        if ($editForm->isSubmitted() && $editForm->isValid()) {
            $em = $this->getDoctrine()->getManager();
            $em->persist($ambiente);
            $em->flush();

            return $this->redirectToRoute('ambiente_edit', array('id' => $ambiente->getId()));
        }

        return $this->render('ambiente/edit.html.twig', array(
            'ambiente' => $ambiente,
            'edit_form' => $editForm->createView(),
            'delete_form' => $deleteForm->createView(),
        ));
    }

    /**
     * Deletes a Ambiente entity.
     *
     * @Route("/{id}", name="ambiente_delete")
     * @Method("DELETE")
     */
    public function deleteAction(Request $request, Ambiente $ambiente)
    {
        $form = $this->createDeleteForm($ambiente);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $em = $this->getDoctrine()->getManager();
            $em->remove($ambiente);
            $em->flush();
        }

        return $this->redirectToRoute('ambiente_index');
    }

    /**
     * Creates a form to delete a Ambiente entity.
     *
     * @param Ambiente $ambiente The Ambiente entity
     *
     * @return \Symfony\Component\Form\Form The form
     */
    private function createDeleteForm(Ambiente $ambiente)
    {
        return $this->createFormBuilder()
            ->setAction($this->generateUrl('ambiente_delete', array('id' => $ambiente->getId())))
            ->setMethod('DELETE')
            ->getForm()
        ;
    }
}
