<?php

namespace UBV\SurUbvBundle\Controller;

use UBV\SurUbvBundle\Entity\Candidato;
use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Method;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;use Symfony\Component\HttpFoundation\Request;

/**
 * Candidato controller.
 *
 * @Route("candidato")
 */
class CandidatoController extends Controller
{
    /**
     * Lists all candidato entities.
     *
     * @Route("/", name="candidato_index")
     * @Method("GET")
     */
    public function indexAction()
    {
        $em = $this->getDoctrine()->getManager();

        $candidatos = $em->getRepository('UBVSurUbvBundle:Candidato')->findAll();

        return $this->render('candidato/index.html.twig', array(
            'candidatos' => $candidatos,
        ));
    }

    /**
     * Creates a new candidato entity.
     *
     * @Route("/new", name="candidato_new")
     * @Method({"GET", "POST"})
     */
    public function newAction(Request $request)
    {
        $candidato = new Candidato();
        $form = $this->createForm('UBV\SurUbvBundle\Form\CandidatoType', $candidato);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $em = $this->getDoctrine()->getManager();
            $em->persist($candidato);
            $em->flush();

            return $this->redirectToRoute('candidato_show', array('id' => $candidato->getId()));
        }

        return $this->render('candidato/new.html.twig', array(
            'candidato' => $candidato,
            'form' => $form->createView(),
        ));
    }

    /**
     * Finds and displays a candidato entity.
     *
     * @Route("/{id}", name="candidato_show")
     * @Method("GET")
     */
    public function showAction(Candidato $candidato)
    {
        $deleteForm = $this->createDeleteForm($candidato);

        return $this->render('candidato/show.html.twig', array(
            'candidato' => $candidato,
            'delete_form' => $deleteForm->createView(),
        ));
    }

    /**
     * Displays a form to edit an existing candidato entity.
     *
     * @Route("/{id}/edit", name="candidato_edit")
     * @Method({"GET", "POST"})
     */
    public function editAction(Request $request, Candidato $candidato)
    {
        $deleteForm = $this->createDeleteForm($candidato);
        $editForm = $this->createForm('UBV\SurUbvBundle\Form\CandidatoType', $candidato);
        $editForm->handleRequest($request);

        if ($editForm->isSubmitted() && $editForm->isValid()) {
            $this->getDoctrine()->getManager()->flush();

            return $this->redirectToRoute('candidato_edit', array('id' => $candidato->getId()));
        }

        return $this->render('candidato/edit.html.twig', array(
            'candidato' => $candidato,
            'edit_form' => $editForm->createView(),
            'delete_form' => $deleteForm->createView(),
        ));
    }

    /**
     * Deletes a candidato entity.
     *
     * @Route("/{id}", name="candidato_delete")
     * @Method("DELETE")
     */
    public function deleteAction(Request $request, Candidato $candidato)
    {
        $form = $this->createDeleteForm($candidato);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $em = $this->getDoctrine()->getManager();
            $em->remove($candidato);
            $em->flush();
        }

        return $this->redirectToRoute('candidato_index');
    }

    /**
     * Creates a form to delete a candidato entity.
     *
     * @param Candidato $candidato The candidato entity
     *
     * @return \Symfony\Component\Form\Form The form
     */
    private function createDeleteForm(Candidato $candidato)
    {
        return $this->createFormBuilder()
            ->setAction($this->generateUrl('candidato_delete', array('id' => $candidato->getId())))
            ->setMethod('DELETE')
            ->getForm()
        ;
    }
}
