<?php

namespace UBV\SurUbvBundle\Controller;

use Symfony\Component\HttpFoundation\Request;
use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Method;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use UBV\SurUbvBundle\Entity\Parroquia;
use UBV\SurUbvBundle\Form\ParroquiaType;
use UBV\SurUbvBundle\Entity\Estado;
use UBV\SurUbvBundle\Entity\Municipio;
use UBV\SurUbvBundle\Form\MunicipioType;
use Symfony\Component\HttpFoundation\JsonResponse;

/**
 * Parroquia controller.
 *
 * @Route("/parroquia")
 */
class ParroquiaController extends Controller
{
    /**
     * Lists all Parroquia entities.
     *
     * @Route("/", name="parroquia_index")
     * @Method("GET")
     */
    public function indexAction()
    {
        $em = $this->getDoctrine()->getManager();

        $parroquias = $em->getRepository('UBVSurUbvBundle:Parroquia')->findAll();

        return $this->render('parroquia/index.html.twig', array(
            'parroquias' => $parroquias,
        ));
    }

    
    
    /**
     * 
     * @Route("/parroquias", name="select_parroquias")
     * @Method("POST")
     */
    public function parroquiasAction(Request $request) 
    {
      //die(dump($request));
      $municipio_id = $request->request->get('municipio_id');
      $em = $this->getDoctrine()->getManager();
      $parroquia = $em->getRepository('UBVSurUbvBundle:Parroquia')->findParroquiaByMunicipioId($municipio_id);

      return new JsonResponse($parroquia);
    }

    /**
     * Creates a new Parroquia entity.
     *
     * @Route("/new", name="parroquia_new")
     * @Method({"GET", "POST"})
     */
    public function newAction(Request $request)
    {
        $parroquium = new Parroquia();
        $form = $this->createForm('UBV\SurUbvBundle\Form\ParroquiaType', $parroquium);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $em = $this->getDoctrine()->getManager();
            $em->persist($parroquium);
            $em->flush();

            return $this->redirectToRoute('parroquia_show', array('id' => $parroquium->getId()));
        }

        return $this->render('parroquia/new.html.twig', array(
            'parroquium' => $parroquium,
            'form' => $form->createView(),
        ));
    }

    /**
     * Finds and displays a Parroquia entity.
     *
     * @Route("/{id}", name="parroquia_show")
     * @Method("GET")
     */
    public function showAction(Parroquia $parroquium)
    {
        $deleteForm = $this->createDeleteForm($parroquium);

        return $this->render('parroquia/show.html.twig', array(
            'parroquium' => $parroquium,
            'delete_form' => $deleteForm->createView(),
        ));
    }

    /**
     * Displays a form to edit an existing Parroquia entity.
     *
     * @Route("/{id}/edit", name="parroquia_edit")
     * @Method({"GET", "POST"})
     */
    public function editAction(Request $request, Parroquia $parroquium)
    {
        $deleteForm = $this->createDeleteForm($parroquium);
        $editForm = $this->createForm('UBV\SurUbvBundle\Form\ParroquiaType', $parroquium);
        $editForm->handleRequest($request);

        if ($editForm->isSubmitted() && $editForm->isValid()) {
            $em = $this->getDoctrine()->getManager();
            $em->persist($parroquium);
            $em->flush();

            return $this->redirectToRoute('parroquia_edit', array('id' => $parroquium->getId()));
        }

        return $this->render('parroquia/edit.html.twig', array(
            'parroquium' => $parroquium,
            'edit_form' => $editForm->createView(),
            'delete_form' => $deleteForm->createView(),
        ));
    }

    /**
     * Deletes a Parroquia entity.
     *
     * @Route("/{id}", name="parroquia_delete")
     * @Method("DELETE")
     */
    public function deleteAction(Request $request, Parroquia $parroquium)
    {
        $form = $this->createDeleteForm($parroquium);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $em = $this->getDoctrine()->getManager();
            $em->remove($parroquium);
            $em->flush();
        }

        return $this->redirectToRoute('parroquia_index');
    }

    /**
     * Creates a form to delete a Parroquia entity.
     *
     * @param Parroquia $parroquium The Parroquia entity
     *
     * @return \Symfony\Component\Form\Form The form
     */
    private function createDeleteForm(Parroquia $parroquium)
    {
        return $this->createFormBuilder()
            ->setAction($this->generateUrl('parroquia_delete', array('id' => $parroquium->getId())))
            ->setMethod('DELETE')
            ->getForm()
        ;
    }
}
