<?php

namespace UBV\SurUbvBundle\Controller;

use Symfony\Component\HttpFoundation\Request;
use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Method;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use UBV\SurUbvBundle\Entity\PersonalAdministrativo;
use UBV\SurUbvBundle\Form\PersonalAdministrativoType;

/**
 * PersonalAdministrativo controller.
 *
 * @Route("/personaladministrativo")
 */
class PersonalAdministrativoController extends Controller
{
    /**
     * Lists all PersonalAdministrativo entities.
     *
     * @Route("/", name="personaladministrativo_index")
     * @Method("GET")
     */
    public function indexAction()
    {
        $em = $this->getDoctrine()->getManager();

        $personalAdministrativos = $em->getRepository('UBVSurUbvBundle:PersonalAdministrativo')->findAll();

        return $this->render('personaladministrativo/index.html.twig', array(
            'personalAdministrativos' => $personalAdministrativos,
        ));
    }

    /**
     * Creates a new PersonalAdministrativo entity.
     *
     * @Route("/new", name="personaladministrativo_new")
     * @Method({"GET", "POST"})
     */
    public function newAction(Request $request)
    {
        $personalAdministrativo = new PersonalAdministrativo();
        $form = $this->createForm('UBV\SurUbvBundle\Form\PersonalAdministrativoType', $personalAdministrativo);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $em = $this->getDoctrine()->getManager();
            $em->persist($personalAdministrativo);
            $em->flush();

            return $this->redirectToRoute('personaladministrativo_show', array('id' => $personalAdministrativo->getId()));
        }

        return $this->render('personaladministrativo/new.html.twig', array(
            'personalAdministrativo' => $personalAdministrativo,
            'form' => $form->createView(),
        ));
    }

    /**
     * Finds and displays a PersonalAdministrativo entity.
     *
     * @Route("/{id}", name="personaladministrativo_show")
     * @Method("GET")
     */
    public function showAction(PersonalAdministrativo $personalAdministrativo)
    {
        $deleteForm = $this->createDeleteForm($personalAdministrativo);

        return $this->render('personaladministrativo/show.html.twig', array(
            'personalAdministrativo' => $personalAdministrativo,
            'delete_form' => $deleteForm->createView(),
        ));
    }

    /**
     * Displays a form to edit an existing PersonalAdministrativo entity.
     *
     * @Route("/{id}/edit", name="personaladministrativo_edit")
     * @Method({"GET", "POST"})
     */
    public function editAction(Request $request, PersonalAdministrativo $personalAdministrativo)
    {
        $deleteForm = $this->createDeleteForm($personalAdministrativo);
        $editForm = $this->createForm('UBV\SurUbvBundle\Form\PersonalAdministrativoType', $personalAdministrativo);
        $editForm->handleRequest($request);

        if ($editForm->isSubmitted() && $editForm->isValid()) {
            $em = $this->getDoctrine()->getManager();
            $em->persist($personalAdministrativo);
            $em->flush();

            return $this->redirectToRoute('personaladministrativo_edit', array('id' => $personalAdministrativo->getId()));
        }

        return $this->render('personaladministrativo/edit.html.twig', array(
            'personalAdministrativo' => $personalAdministrativo,
            'edit_form' => $editForm->createView(),
            'delete_form' => $deleteForm->createView(),
        ));
    }

    /**
     * Deletes a PersonalAdministrativo entity.
     *
     * @Route("/{id}", name="personaladministrativo_delete")
     * @Method("DELETE")
     */
    public function deleteAction(Request $request, PersonalAdministrativo $personalAdministrativo)
    {
        $form = $this->createDeleteForm($personalAdministrativo);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $em = $this->getDoctrine()->getManager();
            $em->remove($personalAdministrativo);
            $em->flush();
        }

        return $this->redirectToRoute('personaladministrativo_index');
    }

    /**
     * Creates a form to delete a PersonalAdministrativo entity.
     *
     * @param PersonalAdministrativo $personalAdministrativo The PersonalAdministrativo entity
     *
     * @return \Symfony\Component\Form\Form The form
     */
    private function createDeleteForm(PersonalAdministrativo $personalAdministrativo)
    {
        return $this->createFormBuilder()
            ->setAction($this->generateUrl('personaladministrativo_delete', array('id' => $personalAdministrativo->getId())))
            ->setMethod('DELETE')
            ->getForm()
        ;
    }
}
