<?php

namespace UBV\SurUbvBundle\Controller;

use Symfony\Component\HttpFoundation\Request;
use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Method;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use UBV\SurUbvBundle\Entity\TelefonoCodigoArea;
use UBV\SurUbvBundle\Form\TelefonoCodigoAreaType;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;
use Symfony\Component\HttpFoundation\JsonResponse;


/**
 * TelefonoCodigoArea controller.
 *
 * @Route("/telefonocodigoarea")
 */
class TelefonoCodigoAreaController extends Controller
{
    /**
     * Lists all TelefonoCodigoArea entities.
     *
     * @Route("/", name="telefonocodigoarea_index")
     * @Method("GET")
     */
    public function indexAction()
    {
        $em = $this->getDoctrine()->getManager();

        $telefonoCodigoAreas = $em->getRepository('UBVSurUbvBundle:TelefonoCodigoArea')->findAll();

        return $this->render('telefonocodigoarea/index.html.twig', array(
            'telefonoCodigoAreas' => $telefonoCodigoAreas,
        ));
    }

    /**
     * 
     * @Route("/codigo_area", name="select_codigo")
     * @Method("POST")
     */
    public function codigoAreasAction(Request $request) {
      $telefonoTipo_id = $request->request->get('telefonoTipo_id');
      $em = $this->getDoctrine()->getManager();
      $telefonoCodigoArea = $em->getRepository('UBVSurUbvBundle:TelefonoCodigoArea')->findTelefonoCodigoAreaByTelefonoTipoId($telefonoTipo_id);

      return new JsonResponse($telefonoCodigoArea);
    }

    /**
     * Creates a new TelefonoCodigoArea entity.
     *
     * @Route("/new", name="telefonocodigoarea_new")
     * @Method({"GET", "POST"})
     */
    public function newAction(Request $request)
    {
        $telefonoCodigoArea = new TelefonoCodigoArea();
        $form = $this->createForm('UBV\SurUbvBundle\Form\TelefonoCodigoAreaType', $telefonoCodigoArea);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $em = $this->getDoctrine()->getManager();
            $em->persist($telefonoCodigoArea);
            $em->flush();

            return $this->redirectToRoute('telefonocodigoarea_show', array('id' => $telefonoCodigoArea->getId()));
        }

        return $this->render('telefonocodigoarea/new.html.twig', array(
            'telefonoCodigoArea' => $telefonoCodigoArea,
            'form' => $form->createView(),
        ));
    }

    /**
     * Finds and displays a TelefonoCodigoArea entity.
     *
     * @Route("/{id}", name="telefonocodigoarea_show")
     * @Method("GET")
     */
    public function showAction(TelefonoCodigoArea $telefonoCodigoArea)
    {
        $deleteForm = $this->createDeleteForm($telefonoCodigoArea);

        return $this->render('telefonocodigoarea/show.html.twig', array(
            'telefonoCodigoArea' => $telefonoCodigoArea,
            'delete_form' => $deleteForm->createView(),
        ));
    }

    /**
     * Displays a form to edit an existing TelefonoCodigoArea entity.
     *
     * @Route("/{id}/edit", name="telefonocodigoarea_edit")
     * @Method({"GET", "POST"})
     */
    public function editAction(Request $request, TelefonoCodigoArea $telefonoCodigoArea)
    {
        $deleteForm = $this->createDeleteForm($telefonoCodigoArea);
        $editForm = $this->createForm('UBV\SurUbvBundle\Form\TelefonoCodigoAreaType', $telefonoCodigoArea);
        $editForm->handleRequest($request);

        if ($editForm->isSubmitted() && $editForm->isValid()) {
            $em = $this->getDoctrine()->getManager();
            $em->persist($telefonoCodigoArea);
            $em->flush();

            return $this->redirectToRoute('telefonocodigoarea_edit', array('id' => $telefonoCodigoArea->getId()));
        }

        return $this->render('telefonocodigoarea/edit.html.twig', array(
            'telefonoCodigoArea' => $telefonoCodigoArea,
            'edit_form' => $editForm->createView(),
            'delete_form' => $deleteForm->createView(),
        ));
    }

    /**
     * Deletes a TelefonoCodigoArea entity.
     *
     * @Route("/{id}", name="telefonocodigoarea_delete")
     * @Method("DELETE")
     */
    public function deleteAction(Request $request, TelefonoCodigoArea $telefonoCodigoArea)
    {
        $form = $this->createDeleteForm($telefonoCodigoArea);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $em = $this->getDoctrine()->getManager();
            $em->remove($telefonoCodigoArea);
            $em->flush();
        }

        return $this->redirectToRoute('telefonocodigoarea_index');
    }

    /**
     * Creates a form to delete a TelefonoCodigoArea entity.
     *
     * @param TelefonoCodigoArea $telefonoCodigoArea The TelefonoCodigoArea entity
     *
     * @return \Symfony\Component\Form\Form The form
     */
    private function createDeleteForm(TelefonoCodigoArea $telefonoCodigoArea)
    {
        return $this->createFormBuilder()
            ->setAction($this->generateUrl('telefonocodigoarea_delete', array('id' => $telefonoCodigoArea->getId())))
            ->setMethod('DELETE')
            ->getForm()
        ;
    }
}
