<?php

namespace UBV\SurUbvBundle\Form;

use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;
use UBV\SurUbvBundle\Form\PersonaNacionalidadType;
use Symfony\Component\Form\Extension\Core\Type\DateTimeType;

use Symfony\Component\Form\Extension\Core\Type\CollectionType;

use  Symfony\Component\Validator\Constraints\NotBlank;
use Symfony\Component\Validator\Constraints\Length;

use UBV\SurUbvBundle\Form\EventListener\AddPaisFieldSubscriber;
use UBV\SurUbvBundle\Form\EventListener\AddEstadoFieldSubscriber;
use UBV\SurUbvBundle\Form\EventListener\AddMunicipioFieldSubscriber;
use UBV\SurUbvBundle\Form\EventListener\AddParroquiaFieldSubscriber;
//use UBV\SurUbvBundle\Form\EventListener\AddEjeMunicipalFieldSubscriber;
use UBV\SurUbvBundle\Form\EventListener\AddAldeaFieldSubscriber;
use UBV\SurUbvBundle\Form\EventListener\AddProgramaFieldSubscriber;
//use UBV\SurUbvBundle\Form\EventListener\AddEjeRegionalFieldSubscriber;

use UBV\SurUbvBundle\Entity\PersonaNacionalidad;

use UBV\SurUbvBundle\Form\EstudianteDocumentoType;
use UBV\SurUbvBundle\Entity\EstudianteDocumento;

use Symfony\Component\Form\Extension\Core\Type\ChoiceType;

class AspiranteType extends AbstractType
{
    /**
     * @param FormBuilderInterface $builder
     * @param array $options
     */
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
            //$propertyPathToPais = 'pais';
            $propertyPathToEstado = 'estado';
            $propertyPathToMunicipio = 'municipios';
            //$propertyPathToEjeMunicipal = 'ejemunicipal';
            $propertyPathToParroquia = 'parroquia';
            $propertyPathToAldea = 'aldea';
            $propertyPathToPrograma = 'programa';

        $builder

            ->addEventSubscriber(new AddPaisFieldSubscriber($propertyPathToAldea))
            ->addEventSubscriber(new AddEstadoFieldSubscriber($propertyPathToAldea))
            ->addEventSubscriber(new AddMunicipioFieldSubscriber($propertyPathToAldea))
            ->addEventSubscriber(new AddParroquiaFieldSubscriber($propertyPathToAldea))
            //->addEventSubscriber(new AddEjeRegionalFieldSubscriber($propertyPathToAldea))
            //->addEventSubscriber(new AddEjeMunicipalFieldSubscriber($propertyPathToAldea))
            ->addEventSubscriber(new AddAldeaFieldSubscriber($propertyPathToAldea))
            ->addEventSubscriber(new AddProgramaFieldSubscriber($propertyPathToPrograma))
            ->add('promedio_nota', null, array(
                'constraints'=> new NotBlank(array('groups' => array('Pre-Grado'))),
                'label'=>'Promedio de Notas Bachillerato',
                'attr'       => array('class' => 'form-control','placeholder'=>''),
                'label_attr' => array('class' => 'control-label'),
            ))
                
            ->add('ano_grado', DateTimeType::class, array(
              'widget' => 'single_text',
              'format' => 'yyyyy',
              'label'=> 'Año de Graduación',
              'attr' => array('class' => 'datepicker-years form-control','data-date-format'=>"yyyy" ),
              'label_attr' => array('class' => 'control-label')
            ))
                
            ->add('periodo_asignado', null, array(
                'disabled'=>true,
                'label'=>'Periodo Academico Asignado',
                'attr'       => array('class' => 'form-control','placeholder'=>''),
                'label_attr' => array('class' => 'control-label'),
            ))
                
            ->add('codigo_opsu', null, array(
                'constraints'=> new NotBlank(array('groups' => array('Pre-Grado'))),
                'label'=>'Codigo de OPSU',
                'attr'       => array('class' => 'form-control','placeholder'=>''),
                'label_attr' => array('class' => 'control-label'),
            ))
                
            /*->add('institucion_tipo', null, array(
                'label'=>'Tipo de Institucion Educativa',
                'attr'       => array('class' => 'form-control','placeholder'=>''),
                'label_attr' => array('class' => 'control-label'),
            ))*/
                
              ->add('institucion_tipo',ChoiceType::class, array(
                'label'=>'Tipo de Institución',
                'choices'  => array(
                    'Privada' => 'Privada',
                    'Pública' => 'Publica',
                ),
                'empty_data' => "0",
                'placeholder'=>"Seleccione...",
                'attr'       => array('class' => 'form-control '),
                'label_attr' => array('class' => 'control-label'),
                // *this line is important*
                'choices_as_values' => true,
             ))
            
            ->add('institucion', null, array(
                'label'=>'Institucion Educativa de Graduación',
                'attr'       => array('class' => 'form-control','placeholder'=>''),
                'label_attr' => array('class' => 'control-label'),
            ))
                
            ->add('trabajo',null,array(
                'label'=>"¿Trabaja?"
            ))
                
            ->add('aspiranteTipo', EntityType::class, array(
                'disabled'=>true,
                'class' => 'UBVSurUbvBundle:AspiranteTipo',
                'label'      =>"Tipo de Aspirante",
                'empty_data' => "0",
                'placeholder'=>"Seleccione...",
                'attr'       => array('class' => 'form-control ','placeholder'=>''),
                'label_attr' => array('class' => 'control-label'),
            ))
                
            ->add('gradoAcademico', EntityType::class, array(
                'class' => 'UBVSurUbvBundle:GradoAcademico',
                'label'      =>"Grado Academico",
                'empty_data' => "0",
                'placeholder'=>"Seleccione...",
                'attr'       => array('class' => 'form-control ','placeholder'=>''),
                'label_attr' => array('class' => 'control-label'),
            ))
                
            ->add('aldea', EntityType::class, array(
                'class' => 'UBVSurUbvBundle:Aldea',
                'label'      =>"Aldea",
                'empty_data' => "0",
                'placeholder'=>"Seleccione...",
                'attr'       => array('class' => 'form-control ','placeholder'=>''),
                'label_attr' => array('class' => 'control-label'),
            ))
                
            ->add('programa', EntityType::class, array(
                'class' => 'UBVSurUbvBundle:Programa',
                'label'      =>"Programa de Formación",
                'empty_data' => "0",
                'placeholder'=>"Seleccione...",
                'attr'       => array('class' => 'form-control ','placeholder'=>''),
                'label_attr' => array('class' => 'control-label'),
            ))
                
//            ->add('personaNacionalidads', CollectionType::class, array(
//                'mapped'=>false,
//                'constraints'=> new NotBlank(array('groups' => array('Default'))),
//                'entry_type'     => PersonaNacionalidadType::class,
//                'label'          => 'Nacionalidad',
//                'by_reference'   => true,
//                'prototype_data' => new PersonaNacionalidad(),
//                'allow_delete'   => true,
//                'allow_add'      => true,
//                'attr'           => array('class' => 'row nacionalidad')
//            ))
//                
//            ->add('estudianteDocumentos', CollectionType::class, array(
//                'mapped'=>false,
//                'entry_type'     => EstudianteDocumentoType::class,
//                'allow_add'    => true,
//                'label'          => 'Documento',
//                'by_reference'   => true,
//                'prototype_data' => new EstudianteDocumento(),
//                'allow_delete'   => true,
//                'allow_add'      => true,
//                'attr'           => array('class' => 'row documento')
//            ))
        ;
    }
    
    /**
     * @param OptionsResolver $resolver
     */
    public function configureOptions(OptionsResolver $resolver)
    {
        $resolver->setDefaults(array(
            'data_class' => 'UBV\SurUbvBundle\Entity\Aspirante',
            'constrints' => true,
            'validation_groups' => array("Pre-Grado"),
        ));
    }
}
