<?php

namespace UBV\SurUbvBundle\Form\EventListener;

use Doctrine\ORM\EntityRepository;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\Form\FormEvent;
use Symfony\Component\Form\FormEvents;
use Symfony\Component\PropertyAccess\PropertyAccess;


class AddAldeaFieldSubscriber implements EventSubscriberInterface
{
  private $propertyPathToAldea;
  
  public function __construct($propertyPathToAldea)
  {
    $this->propertyPathToAldea = $propertyPathToAldea;
  }
  
  public static function getSubscribedEvents()
  {
    return array(
      FormEvents::POST_SET_DATA => 'preSetData',
      FormEvents::PRE_SUBMIT => 'preSubmit'
    );
  }

  private function addAldeaForm($form, $parroquia_id, $aldea=null)
  {
    if($parroquia_id === ""){
      $parroquia_id = null;
    }
    
    $formOptions = array(
      'class'       => 'UBVSurUbvBundle:Aldea',
      'placeholder' => 'Seleccione...',
      'mapped' => false,
      'empty_data'  => "0",
      'label'       => 'Aldea',
      'invalid_message'            => 'Por favor seleccione una Aldea',
      'label_attr'  => array('class' => 'control-label'),
      'attr'        => array(
                        'class' => 'detallesSolicitudes_anadir aldea_selector form-control',
                      ),
      'query_builder' => function (EntityRepository $repository) use ($parroquia_id) {
        $qb = $repository->createQueryBuilder('aldea')
          ->innerJoin('aldea.ambiente', 'ambiente')
          ->innerJoin('ambiente.parroquia', 'parroquia')
          ->where('parroquia.id = :parroquia')
          ->setParameter('parroquia', $parroquia_id)
          ;
        return $qb;
      }
    );
    if ($aldea) {  
    $formOptions['data'] = $aldea;

    }
    $form->add('aldea', EntityType::class, $formOptions);
  }

  public function preSetData(FormEvent $event)
  {
    
    $formOptions = array(
      'class'       => 'UBVSurUbvBundle:Aldea',
      'placeholder' => 'Seleccione...',
      'mapped' => false,
      'empty_data'  => "0",
      'label'       => 'Aldea',
      'invalid_message'            => 'Por favor seleccione una Aldea',
      'label_attr'  => array('class' => 'control-label'),
      'attr'        => array(
                  'class' => 'detallesSolicitudes_anadir aldea_selector form-group form-control',
              ),
    );
    
    $data = $event->getData();
    $form = $event->getForm();
    
    if (null === $data) {
      $form->add('aldea', EntityType::class, $formOptions);
      return;
    }
    
    $accessor = PropertyAccess::createPropertyAccessor();
    $aldea = $accessor->getValue($data, $this->propertyPathToAldea);
    $parroquia_id = ($aldea) ? $aldea->getAmbiente()->getParroquia()->getId() : null;
    $this->addAldeaForm($form, $parroquia_id);
  }

  public function preSubmit(FormEvent $event)
  {
    
    $data = $event->getData();
    $form = $event->getForm();
    //die(dump($data));
    $parroquia_id = array_key_exists('parroquia', $data) ? $data['parroquia'] : null;
    $this->addAldeaForm($form, $parroquia_id);
    
  }
}