<?php

namespace UBV\SurUbvBundle\Form\EventListener;

use Symfony\Component\Form\FormEvent;
use Symfony\Component\Form\FormEvents;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\PropertyAccess\PropertyAccess;
use Doctrine\ORM\EntityRepository;
use UBV\SurUbvBundle\Entity\Pais;
use UBV\SurUbvBundle\Entity\Estado;
use UBV\SurUbvBundle\Entity\Municipio;
use UBV\SurUbvBundle\Entity\Parroquia;
use UBV\SurUbvBundle\Entity\Ambiente;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;

class AddAmbienteFieldSubscriber implements EventSubscriberInterface
{
  private $propertyPathToAmbiente;
  
  public function __construct($propertyPathToAmbiente)
  {
    $this->propertyPathToAmbiente = $propertyPathToAmbiente;
  }
  
  public static function getSubscribedEvents()
  {
    return array(
      FormEvents::POST_SET_DATA => 'preSetData',
      FormEvents::PRE_SUBMIT => 'preSubmit'
    );
  }

  private function addAmbienteForm($form, $parroquia_id)
  {
    if($parroquia_id === ""){
      $parroquia_id = null;
    }
    
    $formOptions = array(
      'class'       => 'UBVSurUbvBundle:Ambiente',
      'placeholder' => 'Seleccione...',
      'mapped' => false,
      'empty_data'  => "0",
      'label'       => 'Ambiente',
      'invalid_message'            => 'Por favor seleccione un Municipio',
      'label_attr'  => array('class' => 'control-label'),
      'attr'        => array(
                  'class' => 'detallesSolicitudes_anadir ambiente_selector form-control',
              ),
      'query_builder' => function (EntityRepository $repository) use ($parroquia_id) {
        $qb = $repository->createQueryBuilder('ambiente')
          ->innerJoin('ambiente.parroquia', 'parroquia')
          ->where('parroquia.id = :parroquia')
          ->setParameter('parroquia', $parroquia_id)
          ;
        return $qb;
      }
    );
    
    $form->add('ambiente', EntityType::class, $formOptions);
  }

  public function preSetData(FormEvent $event)
  {
    
    $formOptions = array(
      'class'       => 'UBVSurUbvBundle:Ambiente',
      'placeholder' => 'Seleccione...',
      'mapped' => false,
      'empty_data'  => "0",
      'label'       => 'Ambiente',
      'invalid_message'            => 'Por favor seleccione un Municipio',
      'label_attr'  => array('class' => 'control-label'),
      'attr'        => array(
                  'class' => 'detallesSolicitudes_anadir parroquia_selector form-group form-control',
              ),
    );
    
    $data = $event->getData();
    $form = $event->getForm();
  
    if (null === $data) {
      $form->add('ambiente', EntityType::class, $formOptions);
      return;
    }
    
    $accessor = PropertyAccess::createPropertyAccessor();
    $ambiente = $accessor->getValue($data, $this->propertyPathToAmbiente);
    $parroquia_id = ($ambiente) ? $ambiente->getParroquia()->getId() : null;
    $this->addAmbienteForm($form, $parroquia_id);
  }

  public function preSubmit(FormEvent $event)
  {
    
    $data = $event->getData();
    $form = $event->getForm();
    //die(dump($data));
    $parroquia_id = array_key_exists('parroquia', $data) ? $data['parroquia'] : null;
    $this->addAmbienteForm($form, $parroquia_id);
    
  }
}