<?php

namespace UBV\SurUbvBundle\Form\EventListener;

use Symfony\Component\Form\FormEvent;
use Symfony\Component\Form\FormEvents;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\PropertyAccess\PropertyAccess;
use Doctrine\ORM\EntityRepository;
use UBV\SurUbvBundle\Entity\EjeRegional;
use UBV\SurUbvBundle\Entity\EjeMunicipal;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;

class AddEjeMunicipalFieldSubscriber implements EventSubscriberInterface
{
  private $propertyPathToEjeMunicipal;
  
  public function __construct($propertyPathToEjeMunicipal)
  {
    $this->propertyPathToEjeMunicipal = $propertyPathToEjeMunicipal;
  }
  
  public static function getSubscribedEvents()
  {
    return array(
      FormEvents::POST_SET_DATA => 'preSetData',
      FormEvents::PRE_SUBMIT => 'preSubmit'
    );
  }

  private function addEjeMunicipalForm($form, $ejeRegional_id)
  {
    if($ejeRegional_id === ""){
      $ejeRegional_id = null;
    }
    
    $formOptions = array(
      'class'       => 'UBVSurUbvBundle:EjeMunicipal',
      'placeholder' => 'Seleccione...',
      'mapped' => false,
      'empty_data'  => "0",
      'label'       => 'Eje Geopolitico Municipal',
      'invalid_message'            => 'Por favor seleccione un Eje Geopolitico Municipal',
      'label_attr'  => array('class' => 'control-label'),
      'attr'        => array(
                  'class' => 'detallesSolicitudes_anadir ejemunicipal_selector form-control',
              ),
      'query_builder' => function (EntityRepository $repository) use ($ejeRegional_id) {
        $qb = $repository->createQueryBuilder('ejemunicipal')
          ->innerJoin('ejemunicipal.ejeregional', 'ejeregional')
          ->where('ejeregional.id = :ejeregional')
          ->setParameter('ejeregional', $ejeRegional_id)
          ;
        return $qb;
      }
    );
    $form->add('ejemunicipal', EntityType::class, $formOptions);
  }

  public function preSetData(FormEvent $event)
  {
    
    $formOptions = array(
      'class'       => 'UBVSurUbvBundle:EjeMunicipal',
      'placeholder' => 'Seleccione...',
      'mapped' => false,
      'empty_data'  => "0",
      'label'       => 'Eje Geopolitico Municipal',
      'invalid_message'            => 'Por favor seleccione un Eje Geopolitico Municipal',
      'label_attr'  => array('class' => 'control-label'),
      'attr'        => array(
                  'class' => 'detallesSolicitudes_anadir ejemunicipal_selector form-group form-control',
              ),
    );
    
    $data = $event->getData();
    $form = $event->getForm();
  
    if (null === $data) {
      $form->add('ejemunicipal', EntityType::class, $formOptions);
      return;
    }
    
    $accessor = PropertyAccess::createPropertyAccessor();
    $ejeMunicipal = $accessor->getValue($data, $this->propertyPathToEjeMunicipal);
    $ejeRegional_id = ($ejeMunicipal) ? $ejeMunicipal->getEjeRegional()->getId() : null;
    $this->addEjeMunicipalForm($form, $ejeRegional_id);
  }

  public function preSubmit(FormEvent $event)
  {
    
    $data = $event->getData();
    $form = $event->getForm();
    
    $ejeRegional_id = array_key_exists('ejeregional', $data) ? $data['ejeregional'] : null;
    $this->addEjeMunicipalForm($form, $ejeRegional_id);
  }
}