<?php

namespace UBV\SurUbvBundle\Form\EventListener;

use Symfony\Component\Form\FormEvent;
use Symfony\Component\Form\FormEvents;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\PropertyAccess\PropertyAccess;
use Doctrine\ORM\EntityRepository;
use UBV\SurUbvBundle\Entity\Pais;
use UBV\SurUbvBundle\Entity\Estado;
use UBV\SurUbvBundle\Entity\Municipio;
use UBV\SurUbvBundle\Entity\Parroquia;
use UBV\SurUbvBundle\Entity\Proyecto;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;
use Symfony\Component\Form\FormFactoryInterface;

class AddEstadoFieldSubscriber implements EventSubscriberInterface {

  private $propertyPathToAldea;

  public function __construct($propertyPathToAldea) {
    $this->propertyPathToAldea = $propertyPathToAldea;
  }

  public static function getSubscribedEvents() {
    return array(
        FormEvents::POST_SET_DATA => 'preSetData',
        FormEvents::PRE_SUBMIT => 'preSubmit'
    );
  }

  private function addEstadoForm($form, $pais_id, $estado=null) {
    //die(dump($form));
    if ($pais_id === "") {
      $pais_id = null;
    }

    $formOptions = array(
        'class' => 'UBVSurUbvBundle:Estado',
        'placeholder' => 'Seleccione...',
        'mapped' => false,
        'empty_data' => "0",
        'label' => 'Estado',
        'invalid_message' => 'Por favor seleccione un Estado',
        'label_attr' => array('class' => 'control-label'),
        'attr' => array(
            'class' => 'estado_selector form-control',
        ),
        'query_builder' => function (EntityRepository $repository) use ($pais_id) {
  $qb = $repository->createQueryBuilder('estado')
          ->innerJoin('estado.pais', 'pais')
          ->where('pais.id = :pais')
          ->setParameter('pais', $pais_id)
  ;
  return $qb;
}
    );
    if ($estado) {
      $formOptions['data'] = $estado;
      
    }
    
    $form->add('estado', EntityType::class, $formOptions);
  }

  public function preSetData(FormEvent $event) {

    $formOptions = array(
        'class' => 'UBVSurUbvBundle:Estado',
        'placeholder' => 'Seleccione...',
        'mapped' => false,
        'empty_data' => "0",
        'label' => 'Estado',
        'invalid_message' => 'Por favor seleccione un Estado',
        'label_attr' => array('class' => 'control-label'),
        'attr' => array('class' => 'form-control ','placeholder'=>'ingrese el estado aqui'),
       
    );

    $data = $event->getData();
    $form = $event->getForm();
    
    if (null === $data) {
      $form->add('estado', EntityType::class, $formOptions);
      return;
    }

    $accessor = PropertyAccess::createPropertyAccessor();
    
    $aldea = $accessor->getValue($data, $this->propertyPathToAldea);
    
    $parroquia = ($aldea) ? $aldea->getAmbiente()->getParroquia() : null;
    $municipio = ($parroquia) ? $parroquia->getMunicipio() : null;
    $estado = ($municipio) ? $municipio->getEstado() : null;
    
    $estado = $accessor->getValue($data, $this->propertyPathToAldea);
    $pais_id = ($estado) ? $estado->getPais()->getId() : null;
    $this->addEstadoForm($form, $pais_id, $estado);
  }

  public function preSubmit(FormEvent $event) {

    $data = $event->getData();
    $form = $event->getForm();

    $pais_id = array_key_exists('pais', $data) ? $data['pais'] : null;
    $this->addEstadoForm($form, $pais_id);
  }

}
