<?php

namespace UBV\SurUbvBundle\Form\EventListener;

use Symfony\Component\Form\FormEvent;
use Symfony\Component\Form\FormEvents;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\PropertyAccess\PropertyAccess;
use Doctrine\ORM\EntityRepository;
use UBV\SurUbvBundle\Entity\Pais;
use UBV\SurUbvBundle\Entity\Estado;
use UBV\SurUbvBundle\Entity\Municipio;
use UBV\SurUbvBundle\Entity\Parroquia;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;

class AddMunicipioFieldSubscriber implements EventSubscriberInterface
{
  private $propertyPathToAldea;
  
  public function __construct($propertyPathToAldea)
  {
    $this->propertyPathToAldea = $propertyPathToAldea;
  }
  
  public static function getSubscribedEvents()
  {
    return array(
      FormEvents::POST_SET_DATA => 'preSetData',
      FormEvents::PRE_SUBMIT => 'preSubmit'
    );
  }

  private function addMunicipioForm($form, $estado_id, $municipio = null)
  {
    if($estado_id === ""){
      $estado_id = null;
    }
    
    $formOptions = array(
      'class'       => 'UBVSurUbvBundle:Municipio',
      'placeholder' => 'Seleccione...',
      'mapped' => false,
      'empty_data'  => "0",
      'label'       => 'Municipio',
      'invalid_message'            => 'Por favor seleccione un Municipio',
      'label_attr'  => array('class' => 'control-label'),
      'attr'        => array(
                  'class' => 'detallesSolicitudes_anadir municipio_selector form-control',
              ),
      'query_builder' => function (EntityRepository $repository) use ($estado_id) {
        $qb = $repository->createQueryBuilder('municipio')
          ->innerJoin('municipio.estado', 'estado')
          ->where('estado.id = :estado')
          ->setParameter('estado', $estado_id)
          ;
        return $qb;
      }
    );
    
    if ($municipio) {
      $formOptions['data'] = $municipio;
      
    }
    
    $form->add('municipio', EntityType::class, $formOptions);
  }

  public function preSetData(FormEvent $event)
  {
    
    $formOptions = array(
      'class'       => 'UBVSurUbvBundle:Municipio',
      'placeholder' => 'Seleccione...',
      'mapped' => false,
      'empty_data'  => "0",
      'label'       => 'Municipio',
      'invalid_message'            => 'Por favor seleccione un Municipio',
      'label_attr'  => array('class' => 'control-label'),
      'attr'        => array(
                  'class' => 'detallesSolicitudes_anadir municipio_selector form-group form-control',
              ),
    );
    
    $data = $event->getData();
    $form = $event->getForm();
  
    if (null === $data) {
      $form->add('municipio', EntityType::class, $formOptions);
      return;
    }
    
    $accessor = PropertyAccess::createPropertyAccessor();
    
    $aldea = $accessor->getValue($data, $this->propertyPathToAldea);
    $parroquia = ($aldea) ? $aldea->getAmbiente()->getParroquia() : null;
    //$municipio = $accessor->getValue($data, $this->propertyPathToAldea);
    $municipio = ($parroquia) ? $parroquia->getMunicipio() : null;
    
    $estado_id = ($municipio) ? $municipio->getEstado()->getId() : null;
    $this->addMunicipioForm($form, $estado_id,$municipio);
  }

  public function preSubmit(FormEvent $event)
  {
    
    $data = $event->getData();
    $form = $event->getForm();

    $estado_id = array_key_exists('estado', $data) ? $data['estado'] : null;
    $this->addMunicipioForm($form, $estado_id);
    
  }
}