<?php

namespace UBV\SurUbvBundle\Form\EventListener;

use Symfony\Component\Form\FormEvent;
use Symfony\Component\Form\FormEvents;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\PropertyAccess\PropertyAccess;
use Doctrine\ORM\EntityRepository;
use UBV\SurUbvBundle\Entity\Pais;
use UBV\SurUbvBundle\Entity\Nacionalidad;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;

class AddNacionalidadFieldSubscriber implements EventSubscriberInterface {

  private $propertyPathToNacionalidad;

  public function __construct($propertyPathToNacionalidad) {
    $this->propertyPathToNacionalidad = $propertyPathToNacionalidad;
  }

  public static function getSubscribedEvents() {
    return array(
        FormEvents::POST_SET_DATA => 'preSetData',
        FormEvents::PRE_SUBMIT => 'preSubmit'
    );
  }

  private function addNacionalidadForm($form, $pais_id) {
   
    if ($pais_id === "") {
      $pais_id = null;
    }

    $formOptions = array(
        'class' => 'UBVSurUbvBundle:Nacionalidad',
        'placeholder' => 'Seleccione...',
        //'mapped' => false,
        'empty_data' => "0",
        'label' => 'Código',
        'invalid_message' => 'Por favor seleccione una Nacionalidad',
        'label_attr' => array('class' => 'control-label'),
        'attr' => array(
            'class' => 'detallesSolicitudes_anadir nacionalidad_selector form-control',
        ),
        'query_builder' => function (EntityRepository $repository) use ($pais_id) {
  $qb = $repository->createQueryBuilder('nacionalidad')
          ->innerJoin('nacionalidad.pais', 'pais')
          ->where('pais.id = :pais')
          ->setParameter('pais', $pais_id)
  ;   
  return $qb;
}
    );
    $form->add('nacionalidad', EntityType::class, $formOptions);
  }

  public function preSetData(FormEvent $event) {

    $formOptions = array(
        'class' => 'UBVSurUbvBundle:Nacionalidad',
        'placeholder' => 'Seleccione...',
        //'mapped' => true,
        'empty_data' => "0",
        'label' => 'Código',
        'invalid_message' => 'Por favor seleccione una Nacionalidad',
        'label_attr' => array('class' => 'control-label'),
        'attr' => array(
            'class' => 'detallesSolicitudes_anadir nacionalidad_selector form-group form-control',
        ),
    );

    $data = $event->getData();
    $form = $event->getForm();
    
    if (null === $data) {
      $form->add('nacionalidad', EntityType::class, $formOptions);
      return;
    }

    $accessor = PropertyAccess::createPropertyAccessor();
    $nacionalidad = $accessor->getValue($data, $this->propertyPathToNacionalidad);
    //die(dump($telefonoCodigoArea));
    $pais_id = ($nacionalidad) ? $nacionalidad->getPais()->getId() : null;
    $this->addNacionalidadForm($form, $pais_id);
  }

  public function preSubmit(FormEvent $event) {

    $data = $event->getData();
    $form = $event->getForm();

    $pais_id = array_key_exists('pais', $data) ? $data['pais'] : null;
    $this->addNacionalidadForm($form, $pais_id);
  }

}
