<?php

namespace UBV\SurUbvBundle\Form\EventListener;

use Symfony\Component\Form\FormEvent;
use Symfony\Component\Form\FormEvents;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\PropertyAccess\PropertyAccess;
use Doctrine\ORM\EntityRepository;
//use UBV\SurUbvBundle\Entity\Pais;
//use UBV\SurUbvBundle\Entity\Estado;
//use UBV\SurUbvBundle\Entity\Municipio;
//use UBV\SurUbvBundle\Entity\Parroquia;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;

class AddParroquiaFieldSubscriber implements EventSubscriberInterface
{
  private $propertyPathToAldea;
  
  public function __construct($propertyPathToAldea)
  {
    $this->propertyPathToAldea = $propertyPathToAldea;
  }
  
  public static function getSubscribedEvents()
  {
    return array(
      FormEvents::POST_SET_DATA => 'preSetData',
      FormEvents::PRE_SUBMIT => 'preSubmit'
    );
  }

  private function addParroquiaForm($form, $municipio_id, $parroquia=null)
  {
    if($municipio_id === ""){
      $municipio_id = null;
    }
    
    $formOptions = array(
      'class'       => 'UBVSurUbvBundle:Parroquia',
      'placeholder' => 'Seleccione...',
      'mapped' => false,
      'empty_data'  => "0",
      'label'       => 'Parroquia',
      'invalid_message'            => 'Por favor seleccione una Parroquia',
      'label_attr'  => array('class' => 'control-label'),
      'attr'        => array(
                  'class' => 'detallesSolicitudes_anadir parroquia_selector form-control',
              ),
      'query_builder' => function (EntityRepository $repository) use ($municipio_id) {
        $qb = $repository->createQueryBuilder('parroquia')
          ->innerJoin('parroquia.municipio', 'municipio')
          ->where('municipio.id = :municipio')
          ->setParameter('municipio', $municipio_id)
          ;
        return $qb;
      }
    );
    
    if ($parroquia) {
      $formOptions['data'] = $parroquia;
    }
    
    $form->add('parroquia', EntityType::class, $formOptions);
//    die(dump($formOptions));
  }

  public function preSetData(FormEvent $event)
  {
    
    $formOptions = array(
      'class'       => 'UBVSurUbvBundle:Parroquia',
      'placeholder' => 'Seleccione...',
      'mapped' => false,
      'empty_data'  => "0",
      'label'       => 'Parroquia',
      'invalid_message'            => 'Por favor seleccione una Parroquia',
      'label_attr'  => array('class' => 'control-label'),
      'attr'        => array(
                  'class' => 'detallesSolicitudes_anadir parroquia_selector form-group form-control',
              ),
    );
    
    $data = $event->getData();
    $form = $event->getForm();
  
    if (null === $data) {
      $form->add('parroquia', EntityType::class, $formOptions);
      return;
    }
    
    $accessor = PropertyAccess::createPropertyAccessor();
    
    $aldea = $accessor->getValue($data, $this->propertyPathToAldea);
    //$parroquia = $accessor->getValue($data, $this->propertyPathToAldea);
    $parroquia = ($aldea) ? $aldea->getAmbiente()->getParroquia() : null;
    //$municipio_id = ($parroquia) ? $parroquia->getMunicipio()->getId() : null;
    $municipio_id = ($parroquia) ? $parroquia->getMunicipio()->getId() : null;
    $this->addParroquiaForm($form, $municipio_id, $parroquia);
  }

  public function preSubmit(FormEvent $event)
  {
    
    $data = $event->getData();
    $form = $event->getForm();
    //die(dump($data));
    $municipio_id = array_key_exists('municipio', $data) ? $data['municipio'] : null;
    $this->addParroquiaForm($form, $municipio_id);
    
  }
}
