<?php

namespace UBV\SurUbvBundle\Form\EventListener;

use Symfony\Component\Form\FormEvent;
use Symfony\Component\Form\FormEvents;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\PropertyAccess\PropertyAccess;
use Doctrine\ORM\EntityRepository;
use UBV\SurUbvBundle\Entity\Pais;
use UBV\SurUbvBundle\Entity\Estado;
use UBV\SurUbvBundle\Entity\Municipio;
use UBV\SurUbvBundle\Entity\Parroquia;
use UBV\SurUbvBundle\Entity\Ambiente;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;

class AddProgramaFieldSubscriber implements EventSubscriberInterface
{
  private $propertyPathToPrograma;
  
  public function __construct($propertyPathToPrograma)
  {
    $this->propertyPathToPrograma = $propertyPathToPrograma;
  }
  
  public static function getSubscribedEvents()
  {
    return array(
      FormEvents::POST_SET_DATA => 'preSetData',
      FormEvents::PRE_SUBMIT => 'preSubmit'
    );
  }

  private function addProgramaForm($form, $aldea_id)
  {
    if($aldea_id === ""){
      $aldea_id = null;
    }
    
    $formOptions = array(
      'class'       => 'UBVSurUbvBundle:Programa',
      'placeholder' => 'Seleccione...',
      //'mapped' => false,
      'empty_data'  => "0",
      'label'       => 'Programa',
      'invalid_message'            => 'Por favor seleccione un Programa',
      'label_attr'  => array('class' => 'control-label'),
      'attr'        => array(
                  'class' => 'detallesSolicitudes_anadir programa_selector form-control',
              ),
      'query_builder' => function (EntityRepository $repository) use ($aldea_id) {
        $qb = $repository->createQueryBuilder('programa')
          ->leftJoin('programa.aldeaProgramas', 'aldeaPrograma')
          ->leftJoin('aldeaPrograma.aldea', 'aldea')
          ->where('aldea.id = :aldea')
          ->setParameter('aldea', $aldea_id)
          ;
        return $qb;
      }
    );
    
    $form->add('programa', EntityType::class, $formOptions);
  }

  public function preSetData(FormEvent $event)
  {
    
    $formOptions = array(
      'class'       => 'UBVSurUbvBundle:Programa',
      'placeholder' => 'Seleccione...',
      //'mapped' => false,
      'empty_data'  => "0",
      'label'       => 'Programa',
      'invalid_message'            => 'Por favor seleccione un Programa de Formación',
      'label_attr'  => array('class' => 'control-label'),
      'attr'        => array(
                  'class' => 'detallesSolicitudes_anadir programa_selector form-group form-control',
              ),
    );
    
    $data = $event->getData();
    $form = $event->getForm();
    
    if (null === $data) {
      $form->add('programa', EntityType::class, $formOptions);
      return;
    }
    
    $accessor = PropertyAccess::createPropertyAccessor();
    $programa = $accessor->getValue($data, $this->propertyPathToPrograma);
    $aldea_id = ($programa) ? 1 : null;
    
    $this->addProgramaForm($form, $aldea_id);
  }

  public function preSubmit(FormEvent $event)
  {
    
    $data = $event->getData();
    $form = $event->getForm();
    //die(dump($data));
    $aldea_id = array_key_exists('aldea', $data) ? $data['aldea'] : null;
    $this->addProgramaForm($form, $aldea_id);
    
  }
}