<?php

namespace UBV\SurUbvBundle\Form\EventListener;

use Symfony\Component\Form\FormEvent;
use Symfony\Component\Form\FormEvents;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\PropertyAccess\PropertyAccess;
use Doctrine\ORM\EntityRepository;
use UBV\SurUbvBundle\Entity\TelefonoTipo;
use UBV\SurUbvBundle\Entity\TelefonoCodigoArea;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;

class AddTelefonoCodigoAreaFieldSubscriber implements EventSubscriberInterface {

  private $propertyPathToTelefonoCodigoArea;

  public function __construct($propertyPathToTelefonoCodigoArea) {
    $this->propertyPathToTelefonoCodigoArea = $propertyPathToTelefonoCodigoArea;
  }

  public static function getSubscribedEvents() {
    return array(
        FormEvents::POST_SET_DATA => 'preSetData',
        FormEvents::PRE_SUBMIT => 'preSubmit'
    );
  }

  private function addTelefonoCodigoAreaForm($form, $telefonoTipo_id) {
   
    if ($telefonoTipo_id === "") {
      $telefonoTipo_id = null;
    }

    $formOptions = array(
        'class' => 'UBVSurUbvBundle:TelefonoCodigoArea',
        'placeholder' => 'Seleccione...',
        //'mapped' => false,
        'empty_data' => "0",
        'label' => 'Código',
        'invalid_message' => 'Por favor seleccione un Código de Area',
        'label_attr' => array('class' => 'control-label'),
        'attr' => array(
            'class' => 'detallesSolicitudes_anadir telefonocodigoarea_selector form-control',
        ),
        'query_builder' => function (EntityRepository $repository) use ($telefonoTipo_id) {
  $qb = $repository->createQueryBuilder('telefonoCodigoArea')
          ->innerJoin('telefonoCodigoArea.telefonoTipo', 'telefonoTipo')
          ->where('telefonoTipo.id = :telefonoTipo')
          ->setParameter('telefonoTipo', $telefonoTipo_id)
  ;   
  return $qb;
}
    );
    $form->add('telefonoCodigoArea', EntityType::class, $formOptions);
  }

  public function preSetData(FormEvent $event) {

    $formOptions = array(
        'class' => 'UBVSurUbvBundle:TelefonoCodigoArea',
        'placeholder' => 'Seleccione...',
        //'mapped' => true,
        'empty_data' => "0",
        'label' => 'Código',
        'invalid_message' => 'Por favor seleccione un Código de Area',
        'label_attr' => array('class' => 'control-label'),
        'attr' => array(
            'class' => 'detallesSolicitudes_anadir telefonocodigoarea_selector form-group form-control',
        ),
    );

    $data = $event->getData();
    $form = $event->getForm();
    
    if (null === $data) {
      $form->add('telefonoCodigoArea', EntityType::class, $formOptions);
      return;
    }

    $accessor = PropertyAccess::createPropertyAccessor();
    $telefonoCodigoArea = $accessor->getValue($data, $this->propertyPathToTelefonoCodigoArea);
    //die(dump($telefonoCodigoArea));
    $telefonoTipo_id = ($telefonoCodigoArea) ? $telefonoCodigoArea->getTelefonoTipo()->getId() : null;
    $this->addTelefonoCodigoAreaForm($form, $telefonoTipo_id);
  }

  public function preSubmit(FormEvent $event) {

    $data = $event->getData();
    $form = $event->getForm();

    $telefonoTipo_id = array_key_exists('telefonoTipo', $data) ? $data['telefonoTipo'] : null;
    $this->addTelefonoCodigoAreaForm($form, $telefonoTipo_id);
  }

}
