<?php

namespace UBV\SurUbvBundle\Form\EventListener;

use Symfony\Component\Form\FormEvent;
use Symfony\Component\Form\FormEvents;
use Symfony\Component\PropertyAccess\PropertyAccess;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;
use Doctrine\ORM\EntityRepository;
use Symfony\Component\Validator\Constraints\NotBlank;



class AddTelefonoTipoFieldSubscriber implements EventSubscriberInterface
{
  private $propertyPathToTelefonoCodigoArea;
  
  public function __construct($propertyPathToTelefonoCodigoArea)
  {
    $this->propertyPathToTelefonoCodigoArea = $propertyPathToTelefonoCodigoArea;
  }
  
  public static function getSubscribedEvents()
  {
    return array(
      FormEvents::PRE_SET_DATA => 'preSetData',
      FormEvents::PRE_SUBMIT => 'preSubmit'
    );
  }
  
  private function addTelefonoTipoForm($form, $telefonoTipo = null)
  { 
    $formOptions = array(
      'class' => 'UBVSurUbvBundle:TelefonoTipo',
      'placeholder' => 'Seleccione...',
      'constraints'=> new NotBlank(array('groups' => array('Default'))),
      'mapped' => false,
      'label' => 'Tipo Telefono',
      'label_attr' => array('class' => 'control-label'),
      'attr' => array(
                  'class' => 'detallesSolicitudes_anadir telefonoTipo_selector form-control',
              ),
    );
    
    if ($telefonoTipo) {
      $formOptions['data'] = $telefonoTipo;
    }
    
    $form->add('telefonoTipo', EntityType::class, $formOptions);
  }
    
  public function preSetData(FormEvent $event)
  {
    $formOptions = array(
      'class' => 'UBVSurUbvBundle:TelefonoTipo',
      'placeholder' => 'Seleccione...',
      'constraints'=> new NotBlank(array('groups' => array('Default'))),
      'mapped' => false,
      'label' => 'Tipo Telefono',
      'label_attr' => array('class' => 'control-label'),
      'attr' => array(
                  'class' => 'detallesSolicitudes_anadir telefonoTipo_selector form-group form-control',
              ),
    );
    
    $data = $event->getData();
    $form = $event->getForm();
    
    if (null === $data) {
      $form->add('telefonoTipo', EntityType::class, $formOptions);
      return;
    }
  
    $accessor = PropertyAccess::createPropertyAccessor();
    $telefonoCodigoArea = $accessor->getValue($data, $this->propertyPathToTelefonoCodigoArea);
    
    $telefonoTipo = ($telefonoCodigoArea) ? $telefonoCodigoArea->getTelefonoTipo() : null;
    $this->addTelefonoTipoForm($form, $telefonoTipo);
  }
  
  public function preSubmit(FormEvent $event)
  {
    $form = $event->getForm();
    $this->addTelefonoTipoForm($form);
  }
}